@@ -23,17 +23,19 @@
 #include <QLineEdit>
 #include <QRegularExpression>
 #include <QSplitter>
-#include <QToolButton>
 #include <QTextBrowser>
 #include <QTimer>
+#include <QToolButton>
 
 Q_GLOBAL_STATIC(KCharSelectData, s_data)
 
 class KCharSelectTablePrivate
 {
 public:
-    KCharSelectTablePrivate(KCharSelectTable *q): q(q)
-    {}
+    KCharSelectTablePrivate(KCharSelectTable *qq)
+        : q(qq)
+    {
+    }
 
     KCharSelectTable *const q;
 
@@ -42,13 +44,15 @@ public:
     QVector<uint> chars;
     uint chr;
 
-    void _k_resizeCells();
-    void _k_doubleClicked(const QModelIndex &index);
-    void _k_slotSelectionChanged(const QItemSelection &selected, const QItemSelection &deselected);
+    void resizeCells();
+    void doubleClicked(const QModelIndex &index);
+    void slotSelectionChanged(const QItemSelection &selected, const QItemSelection &deselected);
 };
 
-class Q_DECL_HIDDEN KCharSelect::KCharSelectPrivate
+class KCharSelectPrivate
 {
+    Q_DECLARE_TR_FUNCTIONS(KCharSelect)
+
 public:
     struct HistoryItem {
         uint c;
@@ -58,16 +62,11 @@ public:
 
     enum { MaxHistoryItems = 100 };
 
-    KCharSelectPrivate(KCharSelect *q)
-        : q(q)
+    KCharSelectPrivate(KCharSelect *qq)
+        : q(qq)
     {
     }
 
-    QString tr(const char *str)
-    {
-        return KCharSelect::tr(str);
-    }
-
     KCharSelect *const q;
 
     QToolButton *backButton = nullptr;
@@ -80,10 +79,10 @@ public:
     KCharSelectTable *charTable = nullptr;
     QTextBrowser *detailBrowser = nullptr;
 
-    bool searchMode = false; //a search is active
+    bool searchMode = false; // a search is active
     bool historyEnabled = false;
     bool allPlanesEnabled = false;
-    int inHistory = 0; //index of current char in history
+    int inHistory = 0; // index of current char in history
     QList<HistoryItem> history;
     QObject *actionParent = nullptr;
 
@@ -91,18 +90,18 @@ public:
     void historyAdd(uint c, bool fromSearch, const QString &searchString);
     void showFromHistory(int index);
     void updateBackForwardButtons();
-    void _k_activateSearchLine();
-    void _k_back();
-    void _k_forward();
-    void _k_fontSelected();
-    void _k_charSelected(uint c);
-    void _k_updateCurrentChar(uint c);
-    void _k_slotUpdateUnicode(uint c);
-    void _k_sectionSelected(int index);
-    void _k_blockSelected(int index);
-    void _k_searchEditChanged();
-    void _k_search();
-    void _k_linkClicked(QUrl url);
+    void activateSearchLine();
+    void back();
+    void forward();
+    void fontSelected();
+    void charSelected(uint c);
+    void updateCurrentChar(uint c);
+    void slotUpdateUnicode(uint c);
+    void sectionSelected(int index);
+    void blockSelected(int index);
+    void searchEditChanged();
+    void search();
+    void linkClicked(QUrl url);
 };
 
 /******************************************************************/
@@ -110,7 +109,8 @@ public:
 /******************************************************************/
 
 KCharSelectTable::KCharSelectTable(QWidget *parent, const QFont &_font)
-    : QTableView(parent), d(new KCharSelectTablePrivate(this))
+    : QTableView(parent)
+    , d(new KCharSelectTablePrivate(this))
 {
     d->font = _font;
 
@@ -133,15 +133,14 @@ KCharSelectTable::KCharSelectTable(QWidget *parent, const QFont &_font)
     setDragDropMode(QAbstractItemView::DragDrop);
     setTextElideMode(Qt::ElideNone);
 
-    connect(this, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(_k_doubleClicked(QModelIndex)));
+    connect(this, &KCharSelectTable::doubleClicked, this, [this](const QModelIndex &index) {
+        d->doubleClicked(index);
+    });
 
-    d->_k_resizeCells();
+    d->resizeCells();
 }
 
-KCharSelectTable::~KCharSelectTable()
-{
-    delete d;
-}
+KCharSelectTable::~KCharSelectTable() = default;
 
 void KCharSelectTable::setFont(const QFont &_font)
 {
@@ -150,7 +149,7 @@ void KCharSelectTable::setFont(const QFont &_font)
     if (d->model) {
         d->model->setFont(_font);
     }
-    d->_k_resizeCells();
+    d->resizeCells();
 }
 
 uint KCharSelectTable::chr()
@@ -183,11 +182,13 @@ void KCharSelectTable::setContents(const QVector<uint> &chars)
     auto oldModel = d->model;
     d->model = new KCharSelectItemModel(chars, d->font, this);
     setModel(d->model);
-    d->_k_resizeCells();
+    d->resizeCells();
 
     // Setting a model changes the selectionModel. Make sure to always reconnect.
-    connect(selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-            this, SLOT(_k_slotSelectionChanged(QItemSelection,QItemSelection)));
+    connect(selectionModel(), &QItemSelectionModel::selectionChanged, this, [this](const QItemSelection &selected, const QItemSelection &deselected) {
+        d->slotSelectionChanged(selected, deselected);
+    });
+
     connect(d->model, &KCharSelectItemModel::showCharRequested, this, &KCharSelectTable::showCharRequested);
 
     delete oldModel; // The selection model is thrown away when the model gets destroyed().
@@ -203,7 +204,7 @@ void KCharSelectTable::scrollTo(const QModelIndex &index, ScrollHint hint)
     }
 }
 
-void KCharSelectTablePrivate::_k_slotSelectionChanged(const QItemSelection &selected, const QItemSelection &deselected)
+void KCharSelectTablePrivate::slotSelectionChanged(const QItemSelection &selected, const QItemSelection &deselected)
 {
     Q_UNUSED(deselected);
     if (!model || selected.indexes().isEmpty()) {
@@ -215,7 +216,7 @@ void KCharSelectTablePrivate::_k_slotSelectionChanged(const QItemSelection &sele
     }
     uint c = temp.toUInt();
     chr = c;
-    emit q->focusItemChanged(c);
+    Q_EMIT q->focusItemChanged(c);
 }
 
 void KCharSelectTable::resizeEvent(QResizeEvent *e)
@@ -232,18 +233,20 @@ void KCharSelectTable::resizeEvent(QResizeEvent *e)
         // This can be removed once a fixed Qt version is the lowest requirement for Frameworks.
         auto timer = new QTimer(this);
         timer->setSingleShot(true);
-        connect(timer, &QTimer::timeout, [&,timer]() {
-            d->_k_resizeCells();
+        connect(timer, &QTimer::timeout, [&, timer]() {
+            d->resizeCells();
             timer->deleteLater();
         });
         timer->start(0);
     }
 }
 
-void KCharSelectTablePrivate::_k_resizeCells()
+void KCharSelectTablePrivate::resizeCells()
 {
-    KCharSelectItemModel *model = static_cast<KCharSelectItemModel*>(q->model());
-    if (!model) return;
+    KCharSelectItemModel *model = static_cast<KCharSelectItemModel *>(q->model());
+    if (!model) {
+        return;
+    }
 
     const int viewportWidth = q->viewport()->size().width();
 
@@ -256,7 +259,7 @@ void KCharSelectTablePrivate::_k_resizeCells()
     const QVector<uint> chars = model->chars();
     for (int i = 0; i < chars.size(); ++i) {
         uint thisChar = chars.at(i);
-        if(s_data()->isPrint(thisChar)) {
+        if (s_data()->isPrint(thisChar)) {
             maxCharWidth = qMax(maxCharWidth, fontMetrics.boundingRect(QString::fromUcs4(&thisChar, 1)).width());
         }
     }
@@ -305,11 +308,11 @@ void KCharSelectTablePrivate::_k_resizeCells()
     q->setChar(oldChar);
 }
 
-void KCharSelectTablePrivate::_k_doubleClicked(const QModelIndex &index)
+void KCharSelectTablePrivate::doubleClicked(const QModelIndex &index)
 {
     uint c = model->data(index, KCharSelectItemModel::CharacterRole).toUInt();
     if (s_data()->isPrint(c)) {
-        emit q->activated(c);
+        Q_EMIT q->activated(c);
     }
 }
 
@@ -318,7 +321,7 @@ void KCharSelectTable::keyPressEvent(QKeyEvent *e)
     if (d->model) {
         switch (e->key()) {
         case Qt::Key_Space:
-            emit activated(QChar::Space);
+            Q_EMIT activated(QChar::Space);
             return;
         case Qt::Key_Enter:
         case Qt::Key_Return: {
@@ -327,7 +330,7 @@ void KCharSelectTable::keyPressEvent(QKeyEvent *e)
             }
             uint c = d->model->data(currentIndex(), KCharSelectItemModel::CharacterRole).toUInt();
             if (s_data()->isPrint(c)) {
-                emit activated(c);
+                Q_EMIT activated(c);
             }
             return;
         }
@@ -343,16 +346,15 @@ void KCharSelectTable::keyPressEvent(QKeyEvent *e)
 /******************************************************************/
 
 KCharSelect::KCharSelect(QWidget *parent, const Controls controls)
-    : QWidget(parent), d(new KCharSelectPrivate(this))
+    : QWidget(parent)
+    , d(new KCharSelectPrivate(this))
 {
     initWidget(controls, nullptr);
 }
 
-KCharSelect::KCharSelect(
-    QWidget *parent
-    , QObject *actionParent
-    , const Controls controls)
-    : QWidget(parent), d(new KCharSelectPrivate(this))
+KCharSelect::KCharSelect(QWidget *parent, QObject *actionParent, const Controls controls)
+    : QWidget(parent)
+    , d(new KCharSelectPrivate(this))
 {
     initWidget(controls, actionParent);
 }
@@ -366,8 +368,8 @@ void attachToActionParent(QAction *action, QObject *actionParent, const QList<QK
     action->setParent(actionParent);
 
     if (actionParent->inherits("KActionCollection")) {
-        QMetaObject::invokeMethod(actionParent, "addAction", Q_ARG(QString, action->objectName()), Q_ARG(QAction*, action));
-        QMetaObject::invokeMethod(actionParent, "setDefaultShortcuts", Q_ARG(QAction*, action), Q_ARG(QList<QKeySequence>, shortcuts));
+        QMetaObject::invokeMethod(actionParent, "addAction", Q_ARG(QString, action->objectName()), Q_ARG(QAction *, action));
+        QMetaObject::invokeMethod(actionParent, "setDefaultShortcuts", Q_ARG(QAction *, action), Q_ARG(QList<QKeySequence>, shortcuts));
     } else {
         action->setShortcuts(shortcuts);
     }
@@ -389,14 +391,20 @@ void KCharSelect::initWidget(const Controls controls, QObject *actionParent)
         d->searchLine->setToolTip(tr("Enter a search term or character here", "@info:tooltip"));
 
         QAction *findAction = new QAction(this);
-        connect(findAction, &QAction::triggered, this, [this]() { d->_k_activateSearchLine(); });
+        connect(findAction, &QAction::triggered, this, [this]() {
+            d->activateSearchLine();
+        });
         findAction->setObjectName(QStringLiteral("edit_find"));
         findAction->setText(tr("&Find...", "@action"));
         findAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-find")));
         attachToActionParent(findAction, actionParent, QKeySequence::keyBindings(QKeySequence::Find));
 
-        connect(d->searchLine, SIGNAL(textChanged(QString)), this, SLOT(_k_searchEditChanged()));
-        connect(d->searchLine, SIGNAL(returnPressed()), this, SLOT(_k_search()));
+        connect(d->searchLine, &QLineEdit::textChanged, this, [this]() {
+            d->searchEditChanged();
+        });
+        connect(d->searchLine, &QLineEdit::returnPressed, this, [this]() {
+            d->search();
+        });
     }
 
     if ((SearchLine & controls) && ((FontCombo & controls) || (FontSize & controls) || (BlockCombos & controls))) {
@@ -442,8 +450,12 @@ void KCharSelect::initWidget(const Controls controls, QObject *actionParent)
         forwardAction->setIcon(tmp);
     }
 
-    connect(d->backButton, &QToolButton::clicked, this, [this]() { d->_k_back(); });
-    connect(d->forwardButton, &QToolButton::clicked, this, [this]() { d->_k_forward(); });
+    connect(d->backButton, &QToolButton::clicked, this, [this]() {
+        d->back();
+    });
+    connect(d->forwardButton, &QToolButton::clicked, this, [this]() {
+        d->forward();
+    });
 
     d->sectionCombo = new QComboBox(this);
     d->sectionCombo->setObjectName(QStringLiteral("sectionCombo"));
@@ -457,8 +469,13 @@ void KCharSelect::initWidget(const Controls controls, QObject *actionParent)
     d->sectionCombo->addItems(s_data()->sectionList());
     d->blockCombo->setMinimumWidth(QFontMetrics(QWidget::font()).averageCharWidth() * 25);
 
-    connect(d->sectionCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(_k_sectionSelected(int)));
-    connect(d->blockCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(_k_blockSelected(int)));
+    connect(d->sectionCombo, qOverload<int>(&QComboBox::currentIndexChanged), this, [this](int index) {
+        d->sectionSelected(index);
+    });
+
+    connect(d->blockCombo, qOverload<int>(&QComboBox::currentIndexChanged), this, [this](int index) {
+        d->blockSelected(index);
+    });
 
     d->fontCombo = new QFontComboBox(this);
     comboLayout->addWidget(d->fontCombo);
@@ -473,8 +490,12 @@ void KCharSelect::initWidget(const Controls controls, QObject *actionParent)
     d->fontSizeSpinBox->setSingleStep(1);
     d->fontSizeSpinBox->setToolTip(tr("Set font size", "@info:tooltip"));
 
-    connect(d->fontCombo, SIGNAL(currentIndexChanged(QString)), this, SLOT(_k_fontSelected()));
-    connect(d->fontSizeSpinBox, SIGNAL(valueChanged(int)), this, SLOT(_k_fontSelected()));
+    connect(d->fontCombo, qOverload<int>(&QComboBox::currentIndexChanged), this, [this]() {
+        d->fontSelected();
+    });
+    connect(d->fontSizeSpinBox, &QSpinBox::valueChanged, this, [this]() {
+        d->fontSelected();
+    });
 
     if ((HistoryButtons & controls) || (FontCombo & controls) || (FontSize & controls) || (BlockCombos & controls)) {
         mainLayout->addLayout(comboLayout);
@@ -515,9 +536,13 @@ void KCharSelect::initWidget(const Controls controls, QObject *actionParent)
 
     setCurrentFont(QFont());
 
-    connect(d->charTable, SIGNAL(focusItemChanged(uint)), this, SLOT(_k_updateCurrentChar(uint)));
-    connect(d->charTable, SIGNAL(activated(uint)), this, SLOT(_k_charSelected(uint)));
-    connect(d->charTable, SIGNAL(showCharRequested(uint)), this, SLOT(setCurrentCodePoint(uint)));
+    connect(d->charTable, &KCharSelectTable::focusItemChanged, this, [this](uint c) {
+        d->updateCurrentChar(c);
+    });
+    connect(d->charTable, &KCharSelectTable::activated, this, [this](uint c) {
+        d->charSelected(c);
+    });
+    connect(d->charTable, &KCharSelectTable::showCharRequested, this, &KCharSelect::setCurrentCodePoint);
 
     d->detailBrowser = new QTextBrowser(this);
     if (DetailBrowser & controls) {
@@ -526,25 +551,24 @@ void KCharSelect::initWidget(const Controls controls, QObject *actionParent)
         d->detailBrowser->hide();
     }
     d->detailBrowser->setOpenLinks(false);
-    connect(d->detailBrowser, SIGNAL(anchorClicked(QUrl)), this, SLOT(_k_linkClicked(QUrl)));
+    connect(d->detailBrowser, &QTextBrowser::anchorClicked, this, [this](const QUrl &url) {
+        d->linkClicked(url);
+    });
 
     setFocusPolicy(Qt::StrongFocus);
-    if(SearchLine & controls) {
+    if (SearchLine & controls) {
         setFocusProxy(d->searchLine);
     } else {
         setFocusProxy(d->charTable);
     }
 
-    d->_k_sectionSelected(0); // this will also call _k_blockSelected(0)
+    d->sectionSelected(0); // this will also call blockSelected(0)
     setCurrentCodePoint(QChar::Null);
 
     d->historyEnabled = true;
 }
 
-KCharSelect::~KCharSelect()
-{
-    delete d;
-}
+KCharSelect::~KCharSelect() = default;
 
 QSize KCharSelect::sizeHint() const
 {
@@ -555,7 +579,7 @@ void KCharSelect::setCurrentFont(const QFont &_font)
 {
     d->fontCombo->setCurrentFont(_font);
     d->fontSizeSpinBox->setValue(_font.pointSize());
-    d->_k_fontSelected();
+    d->fontSelected();
 }
 
 void KCharSelect::setAllPlanesEnabled(bool all)
@@ -636,20 +660,20 @@ void KCharSelect::setCurrentCodePoint(uint c)
     d->charTable->setChar(c);
 }
 
-void KCharSelect::KCharSelectPrivate::historyAdd(uint c, bool fromSearch, const QString &searchString)
+void KCharSelectPrivate::historyAdd(uint c, bool fromSearch, const QString &searchString)
 {
-    //qCDebug(KWidgetsAddonsLog) << "about to add char" << c << "fromSearch" << fromSearch << "searchString" << searchString;
+    // qCDebug(KWidgetsAddonsLog) << "about to add char" << c << "fromSearch" << fromSearch << "searchString" << searchString;
 
     if (!historyEnabled) {
         return;
     }
 
     if (!history.isEmpty() && c == history.last().c) {
-        //avoid duplicates
+        // avoid duplicates
         return;
     }
 
-    //behave like a web browser, i.e. if user goes back from B to A then clicks C, B is forgotten
+    // behave like a web browser, i.e. if user goes back from B to A then clicks C, B is forgotten
     while (!history.isEmpty() && inHistory != history.count() - 1) {
         history.removeLast();
     }
@@ -668,7 +692,7 @@ void KCharSelect::KCharSelectPrivate::historyAdd(uint c, bool fromSearch, const
     updateBackForwardButtons();
 }
 
-void KCharSelect::KCharSelectPrivate::showFromHistory(int index)
+void KCharSelectPrivate::showFromHistory(int index)
 {
     Q_ASSERT(index >= 0 && index < history.count());
     Q_ASSERT(index != inHistory);
@@ -677,16 +701,16 @@ void KCharSelect::KCharSelectPrivate::showFromHistory(int index)
     updateBackForwardButtons();
 
     const HistoryItem &item = history[index];
-    //qCDebug(KWidgetsAddonsLog) << "index" << index << "char" << item.c << "fromSearch" << item.fromSearch
+    // qCDebug(KWidgetsAddonsLog) << "index" << index << "char" << item.c << "fromSearch" << item.fromSearch
     //    << "searchString" << item.searchString;
 
-    //avoid adding an item from history into history again
+    // avoid adding an item from history into history again
     bool oldHistoryEnabled = historyEnabled;
     historyEnabled = false;
     if (item.fromSearch) {
         if (searchLine->text() != item.searchString) {
             searchLine->setText(item.searchString);
-            _k_search();
+            search();
         }
         charTable->setChar(item.c);
     } else {
@@ -696,54 +720,54 @@ void KCharSelect::KCharSelectPrivate::showFromHistory(int index)
     historyEnabled = oldHistoryEnabled;
 }
 
-void KCharSelect::KCharSelectPrivate::updateBackForwardButtons()
+void KCharSelectPrivate::updateBackForwardButtons()
 {
     backButton->setEnabled(inHistory > 0);
     forwardButton->setEnabled(inHistory < history.count() - 1);
 }
 
-void KCharSelect::KCharSelectPrivate::_k_activateSearchLine()
+void KCharSelectPrivate::activateSearchLine()
 {
     searchLine->setFocus();
     searchLine->selectAll();
 }
 
-void KCharSelect::KCharSelectPrivate::_k_back()
+void KCharSelectPrivate::back()
 {
     Q_ASSERT(inHistory > 0);
     showFromHistory(inHistory - 1);
 }
 
-void KCharSelect::KCharSelectPrivate::_k_forward()
+void KCharSelectPrivate::forward()
 {
     Q_ASSERT(inHistory + 1 < history.count());
     showFromHistory(inHistory + 1);
 }
 
-void KCharSelect::KCharSelectPrivate::_k_fontSelected()
+void KCharSelectPrivate::fontSelected()
 {
     QFont font = fontCombo->currentFont();
     font.setPointSize(fontSizeSpinBox->value());
     charTable->setFont(font);
-    emit q->currentFontChanged(font);
+    Q_EMIT q->currentFontChanged(font);
 }
 
-void KCharSelect::KCharSelectPrivate::_k_charSelected(uint c)
+void KCharSelectPrivate::charSelected(uint c)
 {
     if (!allPlanesEnabled) {
-        emit q->charSelected(QChar(c));
+        Q_EMIT q->charSelected(QChar(c));
     }
-    emit q->codePointSelected(c);
+    Q_EMIT q->codePointSelected(c);
 }
 
-void KCharSelect::KCharSelectPrivate::_k_updateCurrentChar(uint c)
+void KCharSelectPrivate::updateCurrentChar(uint c)
 {
     if (!allPlanesEnabled) {
-        emit q->currentCharChanged(QChar(c));
+        Q_EMIT q->currentCharChanged(QChar(c));
     }
-    emit q->currentCodePointChanged(c);
+    Q_EMIT q->currentCodePointChanged(c);
     if (searchMode) {
-        //we are in search mode. make the two comboboxes show the section & block for this character.
+        // we are in search mode. make the two comboboxes show the section & block for this character.
         //(when we are not in search mode the current character always belongs to the current section & block.)
         int block = s_data()->blockIndex(c);
         int section = s_data()->sectionIndex(block);
@@ -758,17 +782,17 @@ void KCharSelect::KCharSelectPrivate::_k_updateCurrentChar(uint c)
         historyAdd(c, searchMode, searchLine->text());
     }
 
-    _k_slotUpdateUnicode(c);
+    slotUpdateUnicode(c);
 }
 
-void KCharSelect::KCharSelectPrivate::_k_slotUpdateUnicode(uint c)
+void KCharSelectPrivate::slotUpdateUnicode(uint c)
 {
-    QString html = QLatin1String("<p>") + tr("Character:") + QLatin1Char(' ') + s_data()->display(c, charTable->font()) + QLatin1Char(' ') +
-                   s_data()->formatCode(c)  + QLatin1String("<br />");
+    QString html = QLatin1String("<p>") + tr("Character:") + QLatin1Char(' ') + s_data()->display(c, charTable->font()) + QLatin1Char(' ')
+        + s_data()->formatCode(c) + QLatin1String("<br />");
 
     QString name = s_data()->name(c);
     if (!name.isEmpty()) {
-        //is name ever empty? </p> should always be there...
+        // is name ever empty? </p> should always be there...
         html += tr("Name: ") + name.toHtmlEscaped() + QLatin1String("</p>");
     }
     const QStringList aliases = s_data()->aliases(c);
@@ -829,7 +853,7 @@ void KCharSelect::KCharSelectPrivate::_k_slotUpdateUnicode(uint c)
     }
 
     if (!decomposition.isEmpty()) {
-        html += QLatin1String("<p style=\"margin-bottom: 0px;\">") +  tr("Decomposition:") + QLatin1String("</p><ul style=\"margin-top: 0px;\">");
+        html += QLatin1String("<p style=\"margin-bottom: 0px;\">") + tr("Decomposition:") + QLatin1String("</p><ul style=\"margin-top: 0px;\">");
         for (uint c2 : decomposition) {
             if (!allPlanesEnabled && QChar::requiresSurrogates(c2)) {
                 continue;
@@ -919,9 +943,9 @@ void KCharSelect::KCharSelectPrivate::_k_slotUpdateUnicode(uint c)
     detailBrowser->setHtml(html);
 }
 
-QString KCharSelect::KCharSelectPrivate::createLinks(QString s)
+QString KCharSelectPrivate::createLinks(QString s)
 {
-    const QRegularExpression rx(QStringLiteral("\\b([\\dABCDEF]{4,5})\\b"));
+    static const QRegularExpression rx(QStringLiteral("\\b([\\dABCDEF]{4,5})\\b"), QRegularExpression::UseUnicodePropertiesOption);
     QRegularExpressionMatchIterator iter = rx.globalMatch(s);
     QRegularExpressionMatch match;
     QSet<QString> chars;
@@ -930,7 +954,7 @@ QString KCharSelect::KCharSelectPrivate::createLinks(QString s)
         chars.insert(match.captured(1));
     }
 
-    for (const QString &c : qAsConst(chars)) {
+    for (const QString &c : std::as_const(chars)) {
         int unicode = c.toInt(nullptr, 16);
         if (!allPlanesEnabled && QChar::requiresSurrogates(unicode)) {
             continue;
@@ -946,7 +970,7 @@ QString KCharSelect::KCharSelectPrivate::createLinks(QString s)
     return s;
 }
 
-void KCharSelect::KCharSelectPrivate::_k_sectionSelected(int index)
+void KCharSelectPrivate::sectionSelected(int index)
 {
     blockCombo->clear();
     const QVector<int> blocks = s_data()->sectionContents(index);
@@ -962,36 +986,36 @@ void KCharSelect::KCharSelectPrivate::_k_sectionSelected(int index)
     blockCombo->setCurrentIndex(0);
 }
 
-void KCharSelect::KCharSelectPrivate::_k_blockSelected(int index)
+void KCharSelectPrivate::blockSelected(int index)
 {
     if (index == -1) {
-        //the combo box has been cleared and is about to be filled again (because the section has changed)
+        // the combo box has been cleared and is about to be filled again (because the section has changed)
         return;
     }
     if (searchMode) {
-        //we are in search mode, so don't fill the table with this block.
+        // we are in search mode, so don't fill the table with this block.
         return;
     }
 
     int block = blockCombo->itemData(index).toInt();
     const QVector<uint> contents = s_data()->blockContents(block);
     charTable->setContents(contents);
-    emit q->displayedCharsChanged();
+    Q_EMIT q->displayedCharsChanged();
     charTable->setChar(contents[0]);
 }
 
-void KCharSelect::KCharSelectPrivate::_k_searchEditChanged()
+void KCharSelectPrivate::searchEditChanged()
 {
     if (searchLine->text().isEmpty()) {
         sectionCombo->setEnabled(true);
         blockCombo->setEnabled(true);
 
-        //upon leaving search mode, keep the same character selected
+        // upon leaving search mode, keep the same character selected
         searchMode = false;
         uint c = charTable->chr();
         bool oldHistoryEnabled = historyEnabled;
         historyEnabled = false;
-        _k_blockSelected(blockCombo->currentIndex());
+        blockSelected(blockCombo->currentIndex());
         historyEnabled = oldHistoryEnabled;
         q->setCurrentCodePoint(c);
     } else {
@@ -1000,12 +1024,12 @@ void KCharSelect::KCharSelectPrivate::_k_searchEditChanged()
 
         int length = searchLine->text().length();
         if (length >= 3) {
-            _k_search();
+            search();
         }
     }
 }
 
-void KCharSelect::KCharSelectPrivate::_k_search()
+void KCharSelectPrivate::search()
 {
     if (searchLine->text().isEmpty()) {
         return;
@@ -1023,13 +1047,13 @@ void KCharSelect::KCharSelectPrivate::_k_search()
         }
     }
     charTable->setContents(contents);
-    emit q->displayedCharsChanged();
+    Q_EMIT q->displayedCharsChanged();
     if (!contents.isEmpty()) {
         charTable->setChar(contents[0]);
     }
 }
 
-void  KCharSelect::KCharSelectPrivate::_k_linkClicked(QUrl url)
+void KCharSelectPrivate::linkClicked(QUrl url)
 {
     QString hex = url.toString();
     if (hex.size() > 6) {
@@ -1048,8 +1072,7 @@ void  KCharSelect::KCharSelectPrivate::_k_linkClicked(QUrl url)
 QVariant KCharSelectItemModel::data(const QModelIndex &index, int role) const
 {
     int pos = m_columns * (index.row()) + index.column();
-    if (!index.isValid() || pos < 0 || pos >= m_chars.size()
-            || index.row() < 0 || index.column() < 0) {
+    if (!index.isValid() || pos < 0 || pos >= m_chars.size() || index.row() < 0 || index.column() < 0) {
         if (role == Qt::BackgroundRole) {
             return QVariant(qApp->palette().color(QPalette::Button));
         }
@@ -1058,9 +1081,9 @@ QVariant KCharSelectItemModel::data(const QModelIndex &index, int role) const
 
     uint c = m_chars[pos];
     if (role == Qt::ToolTipRole) {
-        QString result = s_data()->display(c, m_font) + QLatin1String("<br />") + s_data()->name(c).toHtmlEscaped() + QLatin1String("<br />") +
-                         tr("Unicode code point:") + QLatin1Char(' ') + s_data()->formatCode(c) + QLatin1String("<br />") +
-                         tr("In decimal", "Character") + QLatin1Char(' ') + QString::number(c);
+        QString result = s_data()->display(c, m_font) + QLatin1String("<br />") + s_data()->name(c).toHtmlEscaped() + QLatin1String("<br />")
+            + tr("Unicode code point:") + QLatin1Char(' ') + s_data()->formatCode(c) + QLatin1String("<br />") + tr("In decimal", "Character")
+            + QLatin1Char(' ') + QString::number(c);
         return QVariant(result);
     } else if (role == Qt::TextAlignmentRole) {
         return QVariant(Qt::AlignHCenter | Qt::AlignVCenter);
@@ -1103,7 +1126,7 @@ bool KCharSelectItemModel::dropMimeData(const QMimeData *data, Qt::DropAction ac
     if (text.isEmpty()) {
         return false;
     }
-    emit showCharRequested(text.toUcs4().at(0));
+    Q_EMIT showCharRequested(text.toUcs4().at(0));
     return true;
 }
 
@@ -1112,9 +1135,9 @@ void KCharSelectItemModel::setColumnCount(int columns)
     if (columns == m_columns) {
         return;
     }
-    emit layoutAboutToBeChanged();
+    Q_EMIT layoutAboutToBeChanged();
     m_columns = columns;
-    emit layoutChanged();
+    Q_EMIT layoutChanged();
 }
 
 #include "moc_kcharselect.cpp"
